package
Version:
v0.0.0-...-4444f9f
Opens a new window with list of versions in this module.
Published: Feb 6, 2021
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package generate_model Create at 2021-01-29 8:54
Package generate_model Create at 2019-06-18 9:35
func GenerateModel(host, db, user, pwd, pkg, path string) error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.